========
 Basics
========

.. toctree::
   :maxdepth: 2

   interfaces
   externalization
   internalization
   datastructures
   zcml
   autopackage

``nti.externalization``
=======================

.. module:: nti.externalization

The ``nti.externalization`` module has the top-level APIs.

.. autofunction:: nti.externalization.to_external_object
.. autofunction:: nti.externalization.to_external_representation
.. autofunction:: nti.externalization.new_from_external_object
.. autofunction:: nti.externalization.update_from_external_object
